2535ba7006f2 ("src: get rid of printf") uses gmp_vfprintf() which
doesn't exists in mini-gmp.c, this breaks compilation with --mini-gmp.

This patch implements poor man's gmp_vfprintf that takes one single
argument which is what we need.

Signed-off-by: Pablo Neira Ayuso <[email protected]>
---
@Phil: We're still hitting a compilation warning, since libnftables is
       in place, it seems -Wno-sign-compare is ignored.

 include/gmputil.h | 7 ++++---
 src/gmputil.c     | 8 +++++---
 2 files changed, 9 insertions(+), 6 deletions(-)

diff --git a/src/gmputil.c b/src/gmputil.c
index 3cc4e61f5463..098e2ffb8b3e 100644
--- a/src/gmputil.c
+++ b/src/gmputil.c
@@ -145,9 +145,11 @@ void mpz_switch_byteorder(mpz_t rop, unsigned int len)
 /* mini-gmp doesn't have a gmp_printf so we use our own minimal
  * variant here which is able to format a single mpz_t.
  */
-int mpz_printf(const char *f, const mpz_t value)
+int mpz_vfprintf(FILE *fp, const char *f, va_list args)
 {
+       const mpz_t *value = va_arg(args, const mpz_t *);
        int n = 0;
+
        while (*f) {
                if (*f != '%') {
                        if (fputc(*f, stdout) != *f)
@@ -174,7 +176,7 @@ int mpz_printf(const char *f, const mpz_t value)
                        else
                                return -1;
 
-                       len = mpz_sizeinbase(value, base);
+                       len = mpz_sizeinbase(*value, base);
                        while (prec-- > len) {
                                if (fputc('0', stdout) != '0')
                                        return -1;
@@ -182,7 +184,7 @@ int mpz_printf(const char *f, const mpz_t value)
                                ++n;
                        }
 
-                       str = mpz_get_str(NULL, base, value);
+                       str = mpz_get_str(NULL, base, *value);
                        ok = str && fwrite(str, 1, len, stdout) == len;
                        free(str);
 
diff --git a/include/gmputil.h b/include/gmputil.h
index 9c372216cc52..084aa6226687 100644
--- a/include/gmputil.h
+++ b/include/gmputil.h
@@ -7,9 +7,10 @@
 #include <gmp.h>
 #else
 #include <mini-gmp.h>
-/* mini-gmp doesn't come with gmp_printf, so we use our own minimal variant */
-extern int mpz_printf(const char *format, const mpz_t value);
-#define gmp_printf mpz_printf
+#include <stdio.h>
+/* mini-gmp doesn't come with gmp_vfprintf, so we use our own minimal variant 
*/
+extern int mpz_vfprintf(FILE *fp, const char *format, va_list args);
+#define gmp_vfprintf mpz_vfprintf
 #endif
 
 #include <asm/byteorder.h>
-- 
2.11.0

--
To unsubscribe from this list: send the line "unsubscribe netfilter-devel" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to